# Changelog

## 0.6.1

- Fix broken args

## 0.6

- Support timeout arg in subprocess

## 0.5

- Support Python >= 3.6.

## 0.4

- Make prince_bin arg required, do not validate if binary exists.

## 0.3

- Add debug logging.

## 0.2

- Ability to specify custom prince binary.

## 0.1

- Initial version.
